package javax.swing.plaf.metal;

import java.awt.Graphics2D;
import java.awt.Graphics;
import java.awt.Component;
import java.awt.Dimension;
import java.util.Iterator;
import java.util.ArrayList;
import java.util.List;
import sun.awt.AppContext;
import java.awt.GraphicsConfiguration;
import java.awt.Color;
import javax.swing.Icon;

class MetalBumps implements Icon
{
    static final Color ALPHA;
    protected int xBumps;
    protected int yBumps;
    protected Color topColor;
    protected Color shadowColor;
    protected Color backColor;
    private static final Object METAL_BUMPS;
    protected BumpBuffer buffer;
    
    public MetalBumps(int n, int n2, Color color, Color color2, Color color3) {
        this.setBumpArea(n, n2);
        this.setBumpColors(color, color2, color3);
    }
    
    private static BumpBuffer createBuffer(GraphicsConfiguration graphicsConfiguration, Color color, Color color2, Color color3) {
        AppContext appContext = AppContext.getAppContext();
        List<Object> value = (List)appContext.get(MetalBumps.METAL_BUMPS);
        if (value == null) {
            value = new ArrayList();
            appContext.put(MetalBumps.METAL_BUMPS, value);
        }
        for (BumpBuffer bumpBuffer : value) {
            if (bumpBuffer.hasSameConfiguration(graphicsConfiguration, color, color2, color3)) {
                return bumpBuffer;
            }
            continue;
        }
        BumpBuffer o = new BumpBuffer(graphicsConfiguration, color, color2, color3);
        value.add(o);
        return o;
    }
    
    public void setBumpArea(Dimension dimension) {
        this.setBumpArea(dimension.width, dimension.height);
    }
    
    public void setBumpArea(int n, int n2) {
        this.xBumps = n / 2;
        this.yBumps = n2 / 2;
    }
    
    public void setBumpColors(Color topColor, Color shadowColor, Color backColor) {
        this.topColor = topColor;
        this.shadowColor = shadowColor;
        if (backColor == null) {
            this.backColor = MetalBumps.ALPHA;
        }
        else {
            this.backColor = backColor;
        }
    }
    
    @Override
    public void paintIcon(Component component, Graphics graphics, int i, int j) {
        GraphicsConfiguration graphicsConfiguration = (graphics instanceof Graphics2D) ? ((Graphics2D)graphics).getDeviceConfiguration() : null;
        if (this.buffer == null || !this.buffer.hasSameConfiguration(graphicsConfiguration, this.topColor, this.shadowColor, this.backColor)) {
            this.buffer = createBuffer(graphicsConfiguration, this.topColor, this.shadowColor, this.backColor);
        }
        int b = 64;
        int b2 = 64;
        int iconWidth = this.getIconWidth();
        int iconHeight = this.getIconHeight();
        int n = i + iconWidth;
        int n2 = j + iconHeight;
        while (j < n2) {
            int min = Math.min(n2 - j, b2);
            int min2;
            for (; i < n; i += b) {
                min2 = Math.min(n - i, b);
                graphics.drawImage(this.buffer.getImage(), i, j, i + min2, j + min, 0, 0, min2, min, null);
            }
            j += b2;
        }
    }
    
    @Override
    public int getIconWidth() {
        return this.xBumps * 2;
    }
    
    @Override
    public int getIconHeight() {
        return this.yBumps * 2;
    }
    
    static {
        ALPHA = new Color(0, 0, 0, 0);
        METAL_BUMPS = new Object();
    }
}
